;; Generated package description from marginalia.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "marginalia" "2.10.0.20260517.212730" "Enrich existing commands with completion annotations" '((emacs "29.1") (compat "31")) :commit "9a5600ce45fc5736b35322cd310f323e12602e43" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx") ("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '(("Omar Antolín Camarena" . "omar@matem.unam.mx") ("Daniel Mendler" . "mail@daniel-mendler.de")) :keywords '("docs" "help" "matching" "completion") :url "https://github.com/minad/marginalia")
